Struct epp_client::config::EppClientConnection[][src]

pub struct EppClientConnection { /* fields omitted */ }
Connection details to connect to and authenticate with a registry

Implementations

Returns the EPP host and port no as a tuple

Returns the EPP username and password as a tuple

Returns the service extension URIs to be set in the connection to the registry

Returns the parsed client certificate and private key for client TLS auth