Struct epp_client::connection::registry::EppConnection[][src]

pub struct EppConnection {
    pub greeting: String,
    // some fields omitted
}
EPP Connection struct with some metadata for the connection

Fields

greeting: String

Implementations

Create an EppConnection instance with the stream to the registry

Sends an EPP XML request to the registry and return the response receieved to the request