Module domain

Module domain 

Re-exports

pub use check::DomainCheck;
pub use create::DomainCreate;
pub use delete::DomainDelete;
pub use info::DomainInfo;
pub use renew::DomainRenew;
pub use transfer::DomainTransfer;
pub use update::DomainUpdate;

Modules

check
Types for EPP domain check request
create
Types for EPP domain create request
delete
Types for EPP domain delete request
info
Types for EPP domain info request
renew
Types for EPP domain renew request
transfer
Types for EPP domain transfer request
update
Types for EPP domain check request

Structs

DomainAuthInfo
The <authInfo> tag for domain and contact transactions
DomainContact
The <contact> type on domain creation and update requests
HostAttr
The <hostAttr> type for domain transactions
HostAttrList
The list of <hostAttr> types for domain transactions. Typically under an <ns> tag
HostObjList
The list of <hostObj> types for domain transactions. Typically under an <ns> tag
Period
The <period> type for registration, renewal or transfer on domain transactions

Enums

HostList
Enum that can accept one type which corresponds to either the <hostObj> or <hostAttr> list of tags

Constants

ONE_MONTH
ONE_YEAR
SIX_MONTHS
THREE_YEARS
TWO_YEARS
XMLNS