Struct epp_client::epp::object::EppObject[][src]

pub struct EppObject<T: ElementName> {
    pub xmlns: String,
    pub xmlns_xsi: String,
    pub xsi_schema_location: String,
    pub data: T,
}
An EPP XML Document that is used either as an EPP XML request or an EPP XML response

Fields

xmlns: String

XML namespace for the <epp> tag

xmlns_xsi: String

Schema namespace for the <epp> tag

xsi_schema_location: String

Schema location attribute for <epp>

data: T

the request or response object that is set or received in the EPP XML document

Implementations

Create the enclosing EPP XML tag <epp> for data that represents an EPP XML request or response

Creates an EppObject corresponding to the <epp> tag with data for a contact check request

Creates a new EppObject for contact create corresponding to the <epp> tag in EPP XML

Sets the <fax> data for the request

Creates a new EppObject for contact delete corresponding to the <epp> tag in EPP XML

Creates a new EppObject for contact info corresponding to the <epp> tag in EPP XML

Creates a new EppObject for contact update corresponding to the <epp> tag in EPP XML

Sets the data for the <chg> tag for the contact update request

Sets the data for the <fax> tag under <chg> for the contact update request

Sets the data for the <add> tag for the contact update request

Sets the data for the <rem> tag for the contact update request

Loads data into the <chg> tag from an existing EppContactInfoResponse object

Creates a new EppObject for domain check corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain create corresponding to the <epp> tag in EPP XML with the <ns> tag containing <hostObj> tags

Creates a new EppObject for domain create corresponding to the <epp> tag in EPP XML without any nameservers

Creates a new EppObject for domain create corresponding to the <epp> tag in EPP XML without any contacts

Creates a new EppObject for domain create corresponding to the <epp> tag in EPP XML with the <ns> tag containing <hostAttr> tags

Creates a new EppObject for domain delete corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain info corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain renew corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain rgp restore report corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain rgp restore request corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain transfer request corresponding to the <epp> tag in EPP XML

Sets the period for renewal in case of a successful transfer

Creates a new EppObject for domain transfer approval corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain transfer request cancellation corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain transfer rejection corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain transfer request query corresponding to the <epp> tag in EPP XML

Creates a new EppObject for domain update corresponding to the <epp> tag in EPP XML with the <ns> tag containing <hostObj> tags

Sets the data for the <chg> tag

Sets the data for the <add> tag

Sets the data for the <rem> tag

Creates a new EppObject for domain update corresponding to the <epp> tag in EPP XML with the <ns> tag containing <hostAttr> tags

Sets the data for the <chg> tag

Sets the data for the <add> tag

Sets the data for the <rem> tag

Creates a new EppObject for host check corresponding to the <epp> tag in EPP XML

Creates a new EppObject for host create corresponding to the <epp> tag in EPP XML

Creates a new EppObject for host delete corresponding to the <epp> tag in EPP XML

Creates a new EppObject for host info corresponding to the <epp> tag in EPP XML

Creates a new EppObject for host update corresponding to the <epp> tag in EPP XML

Sets the data for the <chg> element of the host update

Sets the data for the <add> element of the host update

Sets the data for the <rem> element of the host update

Creates a new EppObject for <poll> ack corresponding to the <epp> tag in EPP XML

Creates a new EppObject for <poll> req corresponding to the <epp> tag in EPP XML

Creates a new Epp Hello request

Creates a new EPP Login request

Sets the tag data

Sets the tag data

Creates a new EPP Logout request