Module epp_client::epp::response[][src]

Types for EPP responses

Modules

Types for EPP contact responses

Types for EPP domain responses

Types for EPP host responses

Types for EPP message responses

Structs

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to the <response> tag in an EPP response XML without or <resData> sections. Generally used for error handling

Type corresponding to the <response> tag in an EPP response XML containing an <extension> tag

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to the tag in an EPP response XML

Type corresponding to the tag in an EPP response XML

Type corresponding to the tag in the EPP greeting XML

Type corresponding to the tag in an EPP response XML

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to the tag in an EPP response XML

Type corresponding to the tag under in an EPP response XML

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type for data within the section of an EPP greeting

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to in the EPP greeting XML (pending more compliant implementation)

Type corresponding to the tag an EPP response XML

Type Definitions

Type corresponding to the <response> tag in an EPP response without an <extension> section

A generic EPP Response to an EPP command with a result section, a status code and a message

An alias of EppCommandResponse indicating an EPP Error

The EPP Greeting that is received on a successful connection and in response to an EPP hello

An alias of EppCommandResponse received in response to a successful login request

An alias of EppCommandResponse received in response to a successful logout request