Struct epp_client::epp::response::domain::transfer::DomainTransferData[][src]

pub struct DomainTransferData {
    pub name: StringValue,
    pub transfer_status: StringValue,
    pub requester_id: StringValue,
    pub requested_at: StringValue,
    pub ack_id: StringValue,
    pub ack_by: StringValue,
    pub expiring_at: StringValue,
    // some fields omitted
}
Type that represents the <trnData> tag for domain transfer response

Fields

name: StringValue

The domain name

transfer_status: StringValue

The domain transfer status

requester_id: StringValue

The epp user who requested the transfer

requested_at: StringValue

The transfer rquest date

ack_id: StringValue

The epp user who should acknowledge the transfer request

ack_by: StringValue

THe date by which the acknowledgment should be made

expiring_at: StringValue

The domain expiry date