Struct epp_client::epp::response::message::poll::MessageDomainTransferData[][src]

pub struct MessageDomainTransferData {
    pub name: StringValue,
    pub transfer_status: StringValue,
    pub requester_id: StringValue,
    pub requested_at: StringValue,
    pub ack_id: StringValue,
    pub ack_by: StringValue,
    pub expiring_at: StringValue,
    // some fields omitted
}
Type that represents the <trnData> tag for message poll response

Fields

name: StringValue

The name of the domain under transfer

transfer_status: StringValue

The domain transfer status

requester_id: StringValue

The epp user who requested the transfer

requested_at: StringValue

The date of the transfer request

ack_id: StringValue

The epp user who should acknowledge the transfer request

ack_by: StringValue

The date by which the transfer request should be acknowledged

expiring_at: StringValue

The domain expiry date