Struct epp_client::config::EppClientConnection [−][src]
pub struct EppClientConnection { /* fields omitted */ }Expand description
Connection details to connect to and authenticate with a registry
Implementations
Returns the service extension URIs to be set in the connection to the registry
Returns the parsed client certificate and private key for client TLS auth