Struct epp_client::connection::client::EppClient [−][src]
pub struct EppClient { /* fields omitted */ }Expand description
Instances of the EppClient type are used to transact with the registry. Once initialized, the EppClient instance can serialize EPP requests to XML and send them to the registry and deserialize the XML responses from the registry to local types
Implementations
Creates a new EppClient object and does an EPP Login to a given registry to become ready for subsequent transactions on this client instance
Executes an EPP Hello call and returns the response as an EppGreeting
Accepts an EPP request object to convert to a request to send to the registry. The response from the registry is deserialized to response type E and returned.
Accepts raw EPP XML and returns the raw EPP XML response to it. Not recommended for direct use but sometimes can be useful for debugging
Returns the greeting received on establishment of the connection in raw xml form
Returns the greeting received on establishment of the connection as an EppGreeting
Sends the EPP Logout command to log out of the EPP session