Module epp_client::epp::object [−][src]
Data types common to EPP Requests and Responses
Modules
Common data types included in EPP Requests and Responses
Structs
An empty placeholder tag. To be refactored to something more compliant later.
An EPP XML Document that is used either as an EPP XML request or an EPP XML response
Type representing the <extension> tag for an EPP document
The
The
The
Wraps String for easier serialization to and from values that are inner text for tags rather than attributes
Traits
Trait to set correct value for xml tags when tags are being generated from generic types
Trait for StringValue type to add easier conversion from str and String