Struct epp_client::epp::object::EppObject [−][src]
pub struct EppObject<T: ElementName> { pub xmlns: String, pub xmlns_xsi: String, pub xsi_schema_location: String, pub data: T, }
An EPP XML Document that is used either as an EPP XML request or an EPP XML response
Fields
xmlns: StringXML namespace for the <epp> tag
xmlns_xsi: StringSchema namespace for the <epp> tag
xsi_schema_location: StringSchema location attribute for <epp>
data: Tthe request or response object that is set or received in the EPP XML document
Implementations
pub fn new(
id: &str,
email: &str,
postal_info: PostalInfo,
voice: Phone,
auth_password: &str,
client_tr_id: &str
) -> EppContactCreate
pub fn new(
id: &str,
email: &str,
postal_info: PostalInfo,
voice: Phone,
auth_password: &str,
client_tr_id: &str
) -> EppContactCreateCreates a new EppObject for contact create corresponding to the <epp> tag in EPP XML
Creates a new EppObject for contact delete corresponding to the <epp> tag in EPP XML
Creates a new EppObject for contact update corresponding to the <epp> tag in EPP XML
Sets the data for the <chg> tag for the contact update request
Sets the data for the <fax> tag under <chg> for the contact update request
Sets the data for the <add> tag for the contact update request
Sets the data for the <rem> tag for the contact update request
pub fn load_from_epp_contact_info(
&mut self,
contact_info: EppContactInfoResponse
) -> Result<(), Error>
pub fn load_from_epp_contact_info(
&mut self,
contact_info: EppContactInfoResponse
) -> Result<(), Error>Loads data into the <chg> tag from an existing EppContactInfoResponse object
pub fn new_with_ns(
name: &str,
period: u16,
ns: Vec<&str>,
registrant_id: &str,
auth_password: &str,
contacts: Vec<DomainContact>,
client_tr_id: &str
) -> EppDomainCreate
pub fn new_with_ns(
name: &str,
period: u16,
ns: Vec<&str>,
registrant_id: &str,
auth_password: &str,
contacts: Vec<DomainContact>,
client_tr_id: &str
) -> EppDomainCreateCreates a new EppObject for domain create corresponding to the <epp> tag in EPP XML with the <ns> tag containing <hostObj> tags
pub fn new(
name: &str,
period: u16,
registrant_id: &str,
auth_password: &str,
contacts: Vec<DomainContact>,
client_tr_id: &str
) -> EppDomainCreate
pub fn new(
name: &str,
period: u16,
registrant_id: &str,
auth_password: &str,
contacts: Vec<DomainContact>,
client_tr_id: &str
) -> EppDomainCreateCreates a new EppObject for domain create corresponding to the <epp> tag in EPP XML without any nameservers
pub fn new_without_contacts(
name: &str,
period: u16,
auth_password: &str,
client_tr_id: &str
) -> EppDomainCreate
pub fn new_without_contacts(
name: &str,
period: u16,
auth_password: &str,
client_tr_id: &str
) -> EppDomainCreateCreates a new EppObject for domain create corresponding to the <epp> tag in EPP XML without any contacts
pub fn new_with_host_attr(
name: &str,
period: u16,
ns: Vec<HostAttr>,
registrant_id: &str,
auth_password: &str,
contacts: Vec<DomainContact>,
client_tr_id: &str
) -> EppDomainCreateWithHostAttr
pub fn new_with_host_attr(
name: &str,
period: u16,
ns: Vec<HostAttr>,
registrant_id: &str,
auth_password: &str,
contacts: Vec<DomainContact>,
client_tr_id: &str
) -> EppDomainCreateWithHostAttrCreates a new EppObject for domain create corresponding to the <epp> tag in EPP XML with the <ns> tag containing <hostAttr> tags
Creates a new EppObject for domain delete corresponding to the <epp> tag in EPP XML
Creates a new EppObject for domain info corresponding to the <epp> tag in EPP XML
Creates a new EppObject for domain renew corresponding to the <epp> tag in EPP XML
Creates a new EppObject for domain transfer request corresponding to the <epp> tag in EPP XML
Sets the period for renewal in case of a successful transfer
Creates a new EppObject for domain transfer approval corresponding to the <epp> tag in EPP XML
Creates a new EppObject for domain transfer request cancellation corresponding to the <epp> tag in EPP XML
Creates a new EppObject for domain transfer rejection corresponding to the <epp> tag in EPP XML
Creates a new EppObject for domain update corresponding to the <epp> tag in EPP XML with the <ns> tag containing <hostObj> tags
Sets the data for the <chg> tag
Sets the data for the <add> tag
Sets the data for the <rem> tag
Creates a new EppObject for domain update corresponding to the <epp> tag in EPP XML with the <ns> tag containing <hostAttr> tags
Sets the data for the <chg> tag
Sets the data for the <add> tag
Sets the data for the <rem> tag
Creates a new EppObject for host delete corresponding to the <epp> tag in EPP XML
Creates a new EppObject for host info corresponding to the <epp> tag in EPP XML
Creates a new EppObject for host update corresponding to the <epp> tag in EPP XML
Sets the data for the <chg> element of the host update
Sets the data for the <add> element of the host update
Sets the data for the <rem> element of the host update
Creates a new EppObject for <poll> ack corresponding to the <epp> tag in EPP XML
Creates a new EppObject for <poll> req corresponding to the <epp> tag in EPP XML