Struct epp_client::epp::request::domain::update::DomainAddRemove [−][src]
pub struct DomainAddRemove<T> {
pub ns: Option<T>,
pub contacts: Option<Vec<DomainContact>>,
pub statuses: Option<Vec<DomainStatus>>,
}Expand description
Type for elements under the <add> and <rem> tags for domain update
Fields
ns: Option<T>The list of nameservers to add or remove
Type T can be either a HostObjList or HostAttrList
contacts: Option<Vec<DomainContact>>The list of contacts to add to or remove from the domain
statuses: Option<Vec<DomainStatus>>The list of statuses to add to or remove from the domain