Struct epp_client::epp::request::domain::update::DomainUpdateData [−][src]
pub struct DomainUpdateData<T> {
pub xmlns: String,
pub name: StringValue,
pub add: Option<DomainAddRemove<T>>,
pub remove: Option<DomainAddRemove<T>>,
pub change_info: Option<DomainChangeInfo>,
}Expand description
Type for elements under the <update> tag for domain update
Fields
xmlns: StringXML namespace for domain commands
name: StringValueThe name of the domain to update
add: Option<DomainAddRemove<T>>DomainAddRemove Object containing the list of elements to be added
to the domain
remove: Option<DomainAddRemove<T>>DomainAddRemove Object containing the list of elements to be removed
from the domain
change_info: Option<DomainChangeInfo>The data under the <chg> tag for domain update