Struct epp_client::epp::request::host::update::HostAddRemove [−][src]
pub struct HostAddRemove {
pub addresses: Option<Vec<HostAddr>>,
pub statuses: Option<Vec<HostStatus>>,
}Expand description
Type for data under the <add> and <rem> tags
Fields
addresses: Option<Vec<HostAddr>>The IP addresses to be added to or removed from the host
statuses: Option<Vec<HostStatus>>The statuses to be added to or removed from the host