Struct epp_client::epp::response::message::poll::MessageDomainTransferData [−][src]
pub struct MessageDomainTransferData {
pub name: StringValue,
pub transfer_status: StringValue,
pub requester_id: StringValue,
pub requested_at: StringValue,
pub ack_id: StringValue,
pub ack_by: StringValue,
pub expiring_at: StringValue,
// some fields omitted
}Expand description
Type that represents the <trnData> tag for message poll response
Fields
name: StringValueThe name of the domain under transfer
transfer_status: StringValueThe domain transfer status
requester_id: StringValueThe epp user who requested the transfer
requested_at: StringValueThe date of the transfer request
ack_id: StringValueThe epp user who should acknowledge the transfer request
ack_by: StringValueThe date by which the transfer request should be acknowledged
expiring_at: StringValueThe domain expiry date